Contents
========

.. toctree::
   :maxdepth: 2

   intro
   install
   configuration
   plugins
   tutorial
   contributing
   api/index
   changes


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. vi: set et sta sw=3 ts=3:
